@@ -1,5 +1,5 @@
 import click
-from flask import Flask, redirect
+from flask import Flask, redirect, Response
 from flask_redisboard import RedisBoardExtension
 
 
@@ -11,12 +11,12 @@ board = RedisBoardExtension(app)
 
 
 @app.route("/")
-def index():
+def index() -> Response:
     return redirect("/redisboard/dashboard", code=302)
 
 
 @click.command()
 @click.option("--port", default=6999, help="example site port")
-def main(port):
+def main(port: int) -> None:
     click.echo(f"redisboard example is run on port: {port}")
     app.run(port=port)
